// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package config

type LogConfig struct {
	Path       string
	Level      string
	MaxSize    int
	MaxBackups int
	MaxAge     int
	Stacktrace bool
}

type MysqlConfig struct {
	User     string
	Password string
	Addr     string
	DB       string
	Charset  string
	MaxIdle  int
	MaxConn  int
	LogMode  bool
}

type MgoConfig struct {
	User     string
	Password string
	Addr     string
}

type RedisConfig struct {
	Addrs        []string
	Password     string
	DB           int
	PoolSize     int
	MinIdleConns int
	MaxRetries   int
	Cluster      bool
}

type ElasticConfig struct {
	Addrs []string
	Sniff bool
}

type ThirdPartNode struct {
	Host      string
	AppKey    string
	AppSecret string
}

type AliPartNode struct {
	AesKey string
}
type WxNode struct {
	AppletAppId         string
	AppletAppSecret     string
	AppletNotifyUrl     string
	AppletMchId         string
	AppletAppKey        string
	PublicAppId         string
	PublicAppSecret     string
	PublicMsgTmpId      string
	PublicStateMsgTmpId string
}
type ThirdPartyConfig struct {
	Ali AliPartNode
	Wx  WxNode
}

type RPCNode struct {
	ServiceName   string
	ServicePort   int
	ServiceIp     string
	MysqlDb       string
	RedisDb       int
	LogLevel      string
	LogStacktrace bool
}

type KeepaliveConfig struct {
	ClientTime    int
	ClientTimeout int

	ServerTime     int
	ServerTimeout  int
	ServerMiniTime int
}

type OssConfig struct {
	BrandImage      string
	SeriesImage     string
	AccessKeyId     string
	AccessKeySecret string
	Endpoint        string
	Bucket          string
	AvatarBucket    string
	IconBucket      string
	FixBucket       string
	Protocol        string
	RentObj         string
	VoteObj         string
	EventObj        string
	BrandBucket     string
}

type Coupon struct {
	Url        string
	Action     string
	ExpireDate string
}

type RPCConfig struct {
	Prefix     string
	Keepalive  KeepaliveConfig
	Garden     RPCNode
	Common     RPCNode
	System     RPCNode
	Household  RPCNode
	Charge     RPCNode
	Thirdparty RPCNode
	Company    RPCNode
	Device     RPCNode
}

type Configure struct {
	// 基础配置
	K8s     bool
	RunMode string
	Log     LogConfig

	// 按需配置
	Mysql      MysqlConfig
	Redis      RedisConfig
	Mgo        MgoConfig
	Elastic    ElasticConfig
	ThirdParty ThirdPartyConfig
	Oss        OssConfig

	// 所要启用的服务
	Rpc       RPCConfig
	EtcdAddrs []string
}
