// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package impl

import (
	"context"
	"git.getensh.com/common/gopkgs/tasker/rpctasker"
	"google.golang.org/grpc"
	"property-garden/impl/v1/announcement"
	"property-garden/impl/v1/event"
	"property-garden/impl/v1/fee"
	"property-garden/impl/v1/garden"
	"property-garden/impl/v1/house"
	"property-garden/impl/v1/household"
	"property-garden/impl/v1/repair"
	"property-garden/impl/v1/service_phone"
	"property-garden/impl/v1/statistic"
	"property-garden/impl/v1/suggestion"
	"property-garden/impl/v1/system_msg"
	"property-garden/impl/v1/vote"
	"property-garden/pb"
	pb_v1 "property-garden/pb/v1"
)

// 具体实现
type Rcvr struct {
}

func Register(s *grpc.Server) {
	pb.RegisterGardenServer(s, &Rcvr{})
}

func (c *Rcvr) GardenInitDb(ctx context.Context, req *pb_v1.GardenInitDbRequest) (reply *pb_v1.GardenInitDbReply, err error) {
	t1 := func() error {
		reply, err = garden.GardenInitDb(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) GardenHouseIsIn(ctx context.Context, req *pb_v1.GardenHouseIsInRequest) (reply *pb_v1.GardenHouseIsInReply, err error) {
	t1 := func() error {
		reply, err = garden.GardenHouseIsIn(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) BuildingAdd(ctx context.Context, req *pb_v1.BuildingAddRequest) (reply *pb_v1.BuildingAddReply, err error) {
	t1 := func() error {
		reply, err = house.BuildingAdd(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) BuildingUpdate(ctx context.Context, req *pb_v1.BuildingUpdateRequest) (reply *pb_v1.BuildingUpdateReply, err error) {
	t1 := func() error {
		reply, err = house.BuildingUpdate(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) BuildingDel(ctx context.Context, req *pb_v1.BuildingDelRequest) (reply *pb_v1.BuildingDelReply, err error) {
	t1 := func() error {
		reply, err = house.BuildingDel(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) BuildingList(ctx context.Context, req *pb_v1.BuildingListRequest) (reply *pb_v1.BuildingListReply, err error) {
	t1 := func() error {
		reply, err = house.BuildingList(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) BuildingAddManager(ctx context.Context, req *pb_v1.BuildingAddManagerRequest) (reply *pb_v1.BuildingAddManagerReply, err error) {
	t1 := func() error {
		reply, err = house.BuildingAddManager(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) BuildingDelManager(ctx context.Context, req *pb_v1.BuildingDelManagerRequest) (reply *pb_v1.BuildingDelManagerReply, err error) {
	t1 := func() error {
		reply, err = house.BuildingDelManager(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) BuildingManagerList(ctx context.Context, req *pb_v1.BuildingManagerListRequest) (reply *pb_v1.BuildingManagerListReply, err error) {
	t1 := func() error {
		reply, err = house.BuildingManagerList(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) UnitAdd(ctx context.Context, req *pb_v1.UnitAddRequest) (reply *pb_v1.UnitAddReply, err error) {
	t1 := func() error {
		reply, err = house.UnitAdd(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) UnitUpdate(ctx context.Context, req *pb_v1.UnitUpdateRequest) (reply *pb_v1.UnitUpdateReply, err error) {
	t1 := func() error {
		reply, err = house.UnitUpdate(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) UnitDel(ctx context.Context, req *pb_v1.UnitDelRequest) (reply *pb_v1.UnitDelReply, err error) {
	t1 := func() error {
		reply, err = house.UnitDel(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) UnitList(ctx context.Context, req *pb_v1.UnitListRequest) (reply *pb_v1.UnitListReply, err error) {
	t1 := func() error {
		reply, err = house.UnitList(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) HouseAdd(ctx context.Context, req *pb_v1.HouseAddRequest) (reply *pb_v1.HouseAddReply, err error) {
	t1 := func() error {
		reply, err = house.HouseAdd(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) HouseUpdate(ctx context.Context, req *pb_v1.HouseUpdateRequest) (reply *pb_v1.HouseUpdateReply, err error) {
	t1 := func() error {
		reply, err = house.HouseUpdate(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) HouseDel(ctx context.Context, req *pb_v1.HouseDelRequest) (reply *pb_v1.HouseDelReply, err error) {
	t1 := func() error {
		reply, err = house.HouseDel(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) HouseList(ctx context.Context, req *pb_v1.HouseListRequest) (reply *pb_v1.HouseListReply, err error) {
	t1 := func() error {
		reply, err = house.HouseList(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) HouseIds(ctx context.Context, req *pb_v1.HouseIdsRequest) (reply *pb_v1.HouseIdsReply, err error) {
	t1 := func() error {
		reply, err = house.HouseIds(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) HouseInfo(ctx context.Context, req *pb_v1.HouseInfoRequest) (reply *pb_v1.HouseInfoReply, err error) {
	t1 := func() error {
		reply, err = house.HouseInfo(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) HouseholdSync(ctx context.Context, req *pb_v1.HouseholdSyncRequest) (reply *pb_v1.HouseholdSyncReply, err error) {
	t1 := func() error {
		reply, err = household.HouseholdSync(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) HouseholdChange(ctx context.Context, req *pb_v1.HouseholdChangeRequest) (reply *pb_v1.HouseholdChangeReply, err error) {
	t1 := func() error {
		reply, err = household.HouseholdChange(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) GardenHouseholdUserList(ctx context.Context, req *pb_v1.GardenHouseholdUserListRequest) (reply *pb_v1.GardenHouseholdUserListReply, err error) {
	t1 := func() error {
		reply, err = household.GardenHouseholdUserList(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) GardenHouseholdList(ctx context.Context, req *pb_v1.GardenHouseholdListRequest) (reply *pb_v1.GardenHouseholdListReply, err error) {
	t1 := func() error {
		reply, err = household.GardenHouseholdList(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) GardenHouseholdUnitIds(ctx context.Context, req *pb_v1.GardenHouseholdUnitIdsRequest) (reply *pb_v1.GardenHouseholdUnitIdsReply, err error) {
	t1 := func() error {
		reply, err = household.GardenHouseholdUnitIds(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) GardenHouseholdUidsFromUnitId(ctx context.Context, req *pb_v1.GardenHouseholdUidsFromUnitIdRequest) (reply *pb_v1.GardenHouseholdUidsFromUnitIdReply, err error) {
	t1 := func() error {
		reply, err = household.GardenHouseholdUidsFromUnitId(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) BatchHouseAdd(ctx context.Context, req *pb_v1.BatchHouseAddRequest) (reply *pb_v1.BatchHouseAddReply, err error) {
	t1 := func() error {
		reply, err = house.BatchHouseAdd(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 报事报修
func (c *Rcvr) RepairClassList(ctx context.Context, req *pb_v1.RepairClassListRequest) (reply *pb_v1.RepairClassListReply, err error) {
	t1 := func() error {
		reply, err = repair.RepairClassList(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) RepairClassAdd(ctx context.Context, req *pb_v1.RepairClassAddRequest) (reply *pb_v1.RepairClassAddReply, err error) {
	t1 := func() error {
		reply, err = repair.RepairClassAdd(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) RepairClassDel(ctx context.Context, req *pb_v1.RepairClassDelRequest) (reply *pb_v1.RepairClassDelReply, err error) {
	t1 := func() error {
		reply, err = repair.RepairClassDel(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) RepairClassUpdate(ctx context.Context, req *pb_v1.RepairClassUpdateRequest) (reply *pb_v1.RepairClassUpdateReply, err error) {
	t1 := func() error {
		reply, err = repair.RepairClassUpdate(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 报修工单
func (c *Rcvr) RepairOrderList(ctx context.Context, req *pb_v1.RepairOrderListRequest) (reply *pb_v1.RepairOrderListReply, err error) {
	t1 := func() error {
		reply, err = repair.RepairOrderList(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) RepairOrderAdd(ctx context.Context, req *pb_v1.RepairOrderAddRequest) (reply *pb_v1.RepairOrderAddReply, err error) {
	t1 := func() error {
		reply, err = repair.RepairOrderAdd(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) RepairOrderDel(ctx context.Context, req *pb_v1.RepairOrderDelRequest) (reply *pb_v1.RepairOrderDelReply, err error) {
	t1 := func() error {
		reply, err = repair.RepairOrderDel(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) RepairOrderUpdate(ctx context.Context, req *pb_v1.RepairOrderUpdateRequest) (reply *pb_v1.RepairOrderUpdateReply, err error) {
	t1 := func() error {
		reply, err = repair.RepairOrderUpdate(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 派单
func (c *Rcvr) RepairOrderSend(ctx context.Context, req *pb_v1.RepairOrderSendRequest) (reply *pb_v1.RepairOrderSendReply, err error) {
	t1 := func() error {
		reply, err = repair.RepairOrderSend(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 结单
func (c *Rcvr) RepairOrderFinish(ctx context.Context, req *pb_v1.RepairOrderFinishRequest) (reply *pb_v1.RepairOrderFinishReply, err error) {
	t1 := func() error {
		reply, err = repair.RepairOrderFinish(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 退单
func (c *Rcvr) RepairOrderBack(ctx context.Context, req *pb_v1.RepairOrderBackRequest) (reply *pb_v1.RepairOrderBackReply, err error) {
	t1 := func() error {
		reply, err = repair.RepairOrderBack(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 报修工单详情
func (c *Rcvr) RepairOrderInfo(ctx context.Context, req *pb_v1.RepairOrderInfoRequest) (reply *pb_v1.RepairOrderInfoReply, err error) {
	t1 := func() error {
		reply, err = repair.RepairOrderInfo(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 报修回访
func (c *Rcvr) RepairOrderReturnVisit(ctx context.Context, req *pb_v1.RepairOrderReturnVisitRequest) (reply *pb_v1.RepairOrderReturnVisitReply, err error) {
	t1 := func() error {
		reply, err = repair.RepairOrderReturnVisit(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 公告

func (c *Rcvr) AnnouncementAdd(ctx context.Context, req *pb_v1.AnnouncementAddRequest) (reply *pb_v1.AnnouncementAddReply, err error) {
	t1 := func() error {
		reply, err = announcement.AnnouncementAdd(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) AnnouncementReadAdd(ctx context.Context, req *pb_v1.AnnouncementReadAddRequest) (reply *pb_v1.AnnouncementReadAddReply, err error) {
	t1 := func() error {
		reply, err = announcement.AnnouncementReadAdd(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) AnnouncementDel(ctx context.Context, req *pb_v1.AnnouncementDelRequest) (reply *pb_v1.AnnouncementDelReply, err error) {
	t1 := func() error {
		reply, err = announcement.AnnouncementDel(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) AnnouncementUpdate(ctx context.Context, req *pb_v1.AnnouncementUpdateRequest) (reply *pb_v1.AnnouncementUpdateReply, err error) {
	t1 := func() error {
		reply, err = announcement.AnnouncementUpdate(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) AnnouncementList(ctx context.Context, req *pb_v1.AnnouncementListRequest) (reply *pb_v1.AnnouncementListReply, err error) {
	t1 := func() error {
		reply, err = announcement.AnnouncementList(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) SuggestionOrderList(ctx context.Context, req *pb_v1.SuggestionOrderListRequest) (reply *pb_v1.SuggestionOrderListReply, err error) {
	t1 := func() error {
		reply, err = suggestion.SuggestionOrderList(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) SuggestionOrderAdd(ctx context.Context, req *pb_v1.SuggestionOrderAddRequest) (reply *pb_v1.SuggestionOrderAddReply, err error) {
	t1 := func() error {
		reply, err = suggestion.SuggestionOrderAdd(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) SuggestionOrderDel(ctx context.Context, req *pb_v1.SuggestionOrderDelRequest) (reply *pb_v1.SuggestionOrderDelReply, err error) {
	t1 := func() error {
		reply, err = suggestion.SuggestionOrderDel(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) SuggestionOrderUpdate(ctx context.Context, req *pb_v1.SuggestionOrderUpdateRequest) (reply *pb_v1.SuggestionOrderUpdateReply, err error) {
	t1 := func() error {
		reply, err = suggestion.SuggestionOrderUpdate(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 派单
func (c *Rcvr) SuggestionOrderSend(ctx context.Context, req *pb_v1.SuggestionOrderSendRequest) (reply *pb_v1.SuggestionOrderSendReply, err error) {
	t1 := func() error {
		reply, err = suggestion.SuggestionOrderSend(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 结单
func (c *Rcvr) SuggestionOrderFinish(ctx context.Context, req *pb_v1.SuggestionOrderFinishRequest) (reply *pb_v1.SuggestionOrderFinishReply, err error) {
	t1 := func() error {
		reply, err = suggestion.SuggestionOrderFinish(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 退单
func (c *Rcvr) SuggestionOrderBack(ctx context.Context, req *pb_v1.SuggestionOrderBackRequest) (reply *pb_v1.SuggestionOrderBackReply, err error) {
	t1 := func() error {
		reply, err = suggestion.SuggestionOrderBack(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 报修工单详情
func (c *Rcvr) SuggestionOrderInfo(ctx context.Context, req *pb_v1.SuggestionOrderInfoRequest) (reply *pb_v1.SuggestionOrderInfoReply, err error) {
	t1 := func() error {
		reply, err = suggestion.SuggestionOrderInfo(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 报修回访
func (c *Rcvr) SuggestionOrderReturnVisit(ctx context.Context, req *pb_v1.SuggestionOrderReturnVisitRequest) (reply *pb_v1.SuggestionOrderReturnVisitReply, err error) {
	t1 := func() error {
		reply, err = suggestion.SuggestionOrderReturnVisit(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 生成账单
func (c *Rcvr) GenerateBill(ctx context.Context, req *pb_v1.GenerateBillRequest) (reply *pb_v1.GenerateBillReply, err error) {
	t1 := func() error {
		reply, err = fee.GenerateBill(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) GenerateOverdue(ctx context.Context, req *pb_v1.GenerateOverdueRequest) (reply *pb_v1.GenerateOverdueReply, err error) {
	t1 := func() error {
		reply, err = fee.GenerateOverdue(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) GenerateReminder(ctx context.Context, req *pb_v1.GenerateReminderRequest) (reply *pb_v1.GenerateReminderReply, err error) {
	t1 := func() error {
		reply, err = fee.GenerateReminder(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) SystemMsgAdd(ctx context.Context, req *pb_v1.SystemMsgAddRequest) (reply *pb_v1.SystemMsgAddReply, err error) {
	t1 := func() error {
		reply, err = system_msg.SystemMsgAdd(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) SystemMsgList(ctx context.Context, req *pb_v1.SystemMsgListRequest) (reply *pb_v1.SystemMsgListReply, err error) {
	t1 := func() error {
		reply, err = system_msg.SystemMsgList(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) SystemMsgReaded(ctx context.Context, req *pb_v1.SystemMsgReadedRequest) (reply *pb_v1.SystemMsgReadedReply, err error) {
	t1 := func() error {
		reply, err = system_msg.SystemMsgReaded(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) EventAdd(ctx context.Context, req *pb_v1.EventAddRequest) (reply *pb_v1.EventAddReply, err error) {
	t1 := func() error {
		reply, err = event.EventAdd(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) EventUpdate(ctx context.Context, req *pb_v1.EventUpdateRequest) (reply *pb_v1.EventUpdateReply, err error) {
	t1 := func() error {
		reply, err = event.EventUpdate(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) EventDel(ctx context.Context, req *pb_v1.EventDelRequest) (reply *pb_v1.EventDelReply, err error) {
	t1 := func() error {
		reply, err = event.EventDel(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) EventList(ctx context.Context, req *pb_v1.EventListRequest) (reply *pb_v1.EventListReply, err error) {
	t1 := func() error {
		reply, err = event.EventList(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) EventSignAdd(ctx context.Context, req *pb_v1.EventSignAddRequest) (reply *pb_v1.EventSignAddReply, err error) {
	t1 := func() error {
		reply, err = event.EventSignAdd(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) EventSignDel(ctx context.Context, req *pb_v1.EventSignDelRequest) (reply *pb_v1.EventSignDelReply, err error) {
	t1 := func() error {
		reply, err = event.EventSignDel(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) EventSignList(ctx context.Context, req *pb_v1.EventSignListRequest) (reply *pb_v1.EventSignListReply, err error) {
	t1 := func() error {
		reply, err = event.EventSignList(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 服务电话分类
func (c *Rcvr) ServicePhoneClassList(ctx context.Context, req *pb_v1.ServicePhoneClassListRequest) (reply *pb_v1.ServicePhoneClassListReply, err error) {
	t1 := func() error {
		reply, err = service_phone.ServicePhoneClassList(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) ServicePhoneClassAdd(ctx context.Context, req *pb_v1.ServicePhoneClassAddRequest) (reply *pb_v1.ServicePhoneClassAddReply, err error) {
	t1 := func() error {
		reply, err = service_phone.ServicePhoneClassAdd(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) ServicePhoneClassDel(ctx context.Context, req *pb_v1.ServicePhoneClassDelRequest) (reply *pb_v1.ServicePhoneClassDelReply, err error) {
	t1 := func() error {
		reply, err = service_phone.ServicePhoneClassDel(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) ServicePhoneClassUpdate(ctx context.Context, req *pb_v1.ServicePhoneClassUpdateRequest) (reply *pb_v1.ServicePhoneClassUpdateReply, err error) {
	t1 := func() error {
		reply, err = service_phone.ServicePhoneClassUpdate(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 服务电话
func (c *Rcvr) ServicePhoneList(ctx context.Context, req *pb_v1.ServicePhoneListRequest) (reply *pb_v1.ServicePhoneListReply, err error) {
	t1 := func() error {
		reply, err = service_phone.ServicePhoneList(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) ServicePhoneAdd(ctx context.Context, req *pb_v1.ServicePhoneAddRequest) (reply *pb_v1.ServicePhoneAddReply, err error) {
	t1 := func() error {
		reply, err = service_phone.ServicePhoneAdd(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) ServicePhoneDel(ctx context.Context, req *pb_v1.ServicePhoneDelRequest) (reply *pb_v1.ServicePhoneDelReply, err error) {
	t1 := func() error {
		reply, err = service_phone.ServicePhoneDel(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) ServicePhoneUpdate(ctx context.Context, req *pb_v1.ServicePhoneUpdateRequest) (reply *pb_v1.ServicePhoneUpdateReply, err error) {
	t1 := func() error {
		reply, err = service_phone.ServicePhoneUpdate(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) Statistic(ctx context.Context, req *pb_v1.StatisticRequest) (reply *pb_v1.StatisticReply, err error) {
	t1 := func() error {
		reply, err = statistic.Statistic(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}
func (c *Rcvr) RepairStatisticSet(ctx context.Context, req *pb_v1.RepairStatisticSetRequest) (reply *pb_v1.RepairStatisticSetReply, err error) {
	t1 := func() error {
		reply, err = statistic.RepairStatisticSet(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 投票
func (c *Rcvr) VoteList(ctx context.Context, req *pb_v1.VoteListRequest) (reply *pb_v1.VoteListReply, err error) {
	t1 := func() error {
		reply, err = vote.VoteList(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) VoteAdd(ctx context.Context, req *pb_v1.VoteAddRequest) (reply *pb_v1.VoteAddReply, err error) {
	t1 := func() error {
		reply, err = vote.VoteAdd(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) VoteDel(ctx context.Context, req *pb_v1.VoteDelRequest) (reply *pb_v1.VoteDelReply, err error) {
	t1 := func() error {
		reply, err = vote.VoteDel(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

func (c *Rcvr) VoteUpdate(ctx context.Context, req *pb_v1.VoteUpdateRequest) (reply *pb_v1.VoteUpdateReply, err error) {
	t1 := func() error {
		reply, err = vote.VoteUpdate(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 投票回答
func (c *Rcvr) VoteAddAnswer(ctx context.Context, req *pb_v1.VoteAddAnswerRequest) (reply *pb_v1.VoteAddAnswerReply, err error) {
	t1 := func() error {
		reply, err = vote.VoteAddAnswer(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 投票结果列表
func (c *Rcvr) VoteResultList(ctx context.Context, req *pb_v1.VoteResultListRequest) (reply *pb_v1.VoteResultListReply, err error) {
	t1 := func() error {
		reply, err = vote.VoteResultList(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 投票结果统计
func (c *Rcvr) VoteResultStatistic(ctx context.Context, req *pb_v1.VoteResultStatisticRequest) (reply *pb_v1.VoteResultStatisticReply, err error) {
	t1 := func() error {
		reply, err = vote.VoteResultStatistic(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 投票列表，业主小程序专用
func (c *Rcvr) VoteListForHousehold(ctx context.Context, req *pb_v1.VoteListForHouseholdRequest) (reply *pb_v1.VoteListForHouseholdReply, err error) {
	t1 := func() error {
		reply, err = vote.VoteListForHousehold(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}

// 住户退出房屋
func (c *Rcvr) GardenHouseholdDelHouse(ctx context.Context, req *pb_v1.GardenHouseholdDelHouseRequest) (reply *pb_v1.GardenHouseholdDelHouseReply, err error) {
	t1 := func() error {
		reply, err = household.GardenHouseholdDelHouse(ctx, req)
		return err
	}

	return reply, rpctasker.Exec(ctx, t1)
}
