// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package announcement

import (
	"context"
	"encoding/json"
	"fmt"
	"property-garden/errors"
	"property-garden/impl/v1/oss_utils"
	dbmodel "property-garden/model"
	pb_v1 "property-garden/pb/v1"
	"property-garden/utils"
	"time"

	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
)



func checkAnnouncementAddParam(req *pb_v1.AnnouncementAddRequest) error {

	switch {
	case req.GardenId == 0:
		return status.Error(10003, "小区不能为空")
	case req.Title == "":
		return status.Error(10003, "标题不能为空")
	case req.Content == "":
		return status.Error(10003, "内容不能为空")
	}
	return nil
}


func AnnouncementAdd(ctx context.Context, req *pb_v1.AnnouncementAddRequest) (reply *pb_v1.AnnouncementAddReply, err error) {

	reply = &pb_v1.AnnouncementAddReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()
	// 参数检查
	err = checkAnnouncementAddParam(req)
	if err != nil {
		return nil, err
	}
	now := time.Now()
	dbname := utils.GetGardenDbName(req.GardenId)

	p := dbmodel.TAnnouncement{
		Content:req.Content,
		Title:req.Title,
		UpdatedAt:now,
		CreatedAt:now,
	}
	p.SetTable(dbname)

	db := database.DB().Begin()
	err = p.Insert(db)
	if err != nil {
		db.Rollback()
		return nil, errors.DataBaseError
	}
	inList := oss_utils.GetObjFromText(req.Content)
	if len(inList) > 0 {
		if err := oss_utils.OssObjAdd(inList, nil); err != nil {
			db.Rollback()
			return nil, err
		}
	}

	db.Commit()
	reply.Id = p.ID

	return reply, nil
}
