// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package charge

import (
	"context"
	"encoding/json"
	"fmt"
	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
	"gorm.io/gorm"
	"property-garden/errors"
	dbmodel "property-garden/model"
	pb_v1 "property-garden/pb/v1"
	"property-garden/utils"
)



func checkChargeUrgeInfoParam(req *pb_v1.ChargeUrgeInfoRequest) error {
	switch {
	case req.GardenId == 0:
		return status.Error(10003, "小区不能为空")
	}

	return nil

}


func ChargeUrgeInfo(ctx context.Context, req *pb_v1.ChargeUrgeInfoRequest) (reply *pb_v1.ChargeUrgeInfoReply, err error) {

	reply = &pb_v1.ChargeUrgeInfoReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()
	// 参数检查
	err = checkChargeUrgeInfoParam(req)
	if err != nil {
		return nil, err
	}
	dbname := utils.GetGardenDbName(req.GardenId)

	urge := dbmodel.NewChargeUrge(dbname)
	where := map[string]interface{}{
		"id":1,
	}

	err = urge.Find(database.DB(), where)
	if err != nil && err != gorm.ErrRecordNotFound{
		return nil, errors.DataBaseError
	}
	if urge.ID == 0 {
		reply.UrgeDay = 0
		reply.UrgeTarget = 1
		reply.UrgeMsgType = 1
		return reply, nil
	}
	reply.UrgeDay = urge.UrgeDay
	reply.UrgeTarget = urge.UrgeTarget
	reply.UrgeMsgType = urge.UrgeMsgType
	reply.Id = 1
	return reply, nil

}
