// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package charge

import (
	"context"
	"encoding/json"
	"fmt"
	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
	"property-garden/errors"
	dbmodel "property-garden/model"
	pb_v1 "property-garden/pb/v1"
	"property-garden/utils"
)



func checkChargeUrgeSetParam(req *pb_v1.ChargeUrgeSetRequest) error {
	switch {
	case req.GardenId == 0:
		return status.Error(10003, "小区不能为空")
	}

	return nil

}


func ChargeUrgeSet(ctx context.Context, req *pb_v1.ChargeUrgeSetRequest) (reply *pb_v1.ChargeUrgeSetReply, err error) {

	reply = &pb_v1.ChargeUrgeSetReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()
	// 参数检查
	err = checkChargeUrgeSetParam(req)
	if err != nil {
		return nil, err
	}
	dbname := utils.GetGardenDbName(req.GardenId)

	// 先尝试更新
	urge := dbmodel.NewChargeUrge(dbname)
	where := map[string]interface{}{
		"id":1,
	}
	values := map[string]interface{}{
		"urge_day":req.UrgeDay,
		"urge_target":req.UrgeTarget,
		"urge_msg_type":req.UrgeMsgType,
	}

	if req.Id > 0 {
		err := urge.Update(database.DB(), where, values)
		if err != nil {
			return nil, errors.DataBaseError
		}
		return reply, nil
	}

	urge.UrgeMsgType = req.UrgeMsgType
	urge.UrgeTarget = req.UrgeTarget
	urge.UrgeDay = req.UrgeDay
	urge.ID = 1
	err = urge.Insert(database.DB())
	if err != nil {
		return nil, errors.DataBaseError
	}
	return reply, nil

}
