// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package event

import (
	"context"
	"encoding/json"
	"fmt"
	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
	"gorm.io/gorm"
	"property-garden/errors"
	"property-garden/impl/v1/oss_utils"
	dbmodel "property-garden/model"
	pb_v1 "property-garden/pb/v1"
	"property-garden/utils"
	"strings"
)


//
func EventDel(ctx context.Context, req *pb_v1.EventDelRequest) (reply *pb_v1.EventDelReply, err error) {

	reply = &pb_v1.EventDelReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()
	// 参数检查
	if req.Id < 1 || req.GardenId < 1 {
		return nil, errors.ParamsError
	}
	dbname := utils.GetGardenDbName(req.GardenId)
	p := dbmodel.NewEvent(dbname)
	where := map[string]interface{}{
		"id":req.Id,
		//"garden_id":req.GardenId,
	}

	old := dbmodel.NewEvent(dbname)
	err = old.Find(database.DB(), where)
	if err != nil {
		if err != gorm.ErrRecordNotFound {
			return nil, errors.DataBaseError
		}
	}

	db := database.DB().Begin()

	err = p.Delete(db, where)
	if err != nil {
		db.Rollback()
		return nil, errors.DataBaseError
	}
	sign := dbmodel.NewEventSign(dbname)
	where = map[string]interface{}{
		"event_id":req.Id,
	}
	err = sign.Delete(db, where)
	if err != nil {
		db.Rollback()
		return nil, errors.DataBaseError
	}

	outList := oss_utils.GetObjFromText(old.Content)
	pics := strings.Split(old.Pic, ";")
	if len(pics) > 0 {
		outList = append(outList, pics...)
	}
	if len(outList) > 0 {
		if err := oss_utils.OssObjAdd(nil, outList); err != nil {
			db.Rollback()
			return nil, err
		}
	}


	db.Commit()

	return reply, nil
}
