// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package event

import (
	"context"
	"encoding/json"
	"fmt"
	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
	"gorm.io/gorm"
	"property-garden/errors"
	dbmodel "property-garden/model"
	pb_v1 "property-garden/pb/v1"
	"property-garden/utils"
)


func checkEventSignDelParam(req *pb_v1.EventSignDelRequest) error {
	switch {
	case req.GardenId < 1:
		return status.Error(10003, "小区不能为空")
	case req.Id == 0:
		return status.Error(10003, "id不能为空")

	}
	return nil

}



//
func EventSignDel(ctx context.Context, req *pb_v1.EventSignDelRequest) (reply *pb_v1.EventSignDelReply, err error) {

	reply = &pb_v1.EventSignDelReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()
	// 参数检查
	err = checkEventSignDelParam(req)
	if err != nil {
		return nil, err
	}
	dbname := utils.GetGardenDbName(req.GardenId)

	p := dbmodel.NewEventSign(dbname)
	where := map[string]interface{}{
		"id":req.Id,
	}
	err = p.Find(database.DB(), where)
	if err != nil && err != gorm.ErrRecordNotFound {
		return nil, errors.DataBaseError
	}
	if p.ID == 0 {
		return nil, errors.ErrRecordNotFound
	}
	db := database.DB().Begin()
	defer func() {
		if err != nil {
			db.Rollback()
		}
	}()
	err = p.Delete(db, where)
	if err != nil {
		return nil, errors.DataBaseError
	}

	event := dbmodel.NewEvent(dbname)
	where = map[string]interface{}{
		"id":p.EventId,
	}
	values := map[string]interface{}{
		"people_count":gorm.Expr("people_count - ?", p.SignCount),
	}
	err = event.Update(db, where, values)
	if err != nil {
		return nil, errors.DataBaseError
	}
	db.Commit()

	return reply, nil
}
