// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package event

import (
	"context"
	"encoding/json"
	"fmt"
	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
	"property-garden/errors"
	dbmodel "property-garden/model"
	pb_v1 "property-garden/pb/v1"
	"property-garden/utils"
)


//
func EventSignList(ctx context.Context, req *pb_v1.EventSignListRequest) (reply *pb_v1.EventSignListReply, err error) {
	reply = &pb_v1.EventSignListReply{}


	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()
	if req.GardenId < 1 || req.EventId < 1{
		return nil, errors.ParamsError
	}
	if req.Page == 0 {
		req.Page = 1
	}
	if req.PageSize == 0 {
		req.PageSize = 10
	}
	dbname := utils.GetGardenDbName(req.GardenId)
	p := dbmodel.NewEventSign(dbname)
	where := map[string]interface{}{
		"event_id":req.EventId,
	}
	reply.Total, err = p.Count(database.DB(), where, nil)
	if err != nil {
		return nil, errors.DataBaseError
	}
	reply.Page = req.Page
	if reply.Total == 0 {
		return reply, nil
	}
	list, err := p.List(database.DB(), where, nil, int(req.Page), int(req.PageSize))
	if err != nil {
		return nil, errors.DataBaseError
	}


	reply.List = make([]*pb_v1.EventSignItem, len(list))
	for i, v := range list {
		reply.List[i] = &pb_v1.EventSignItem{
			Id:v.ID,
			Name:v.Name,
			Phone:v.Phone,
			Comment:v.Comment,
			Count:v.SignCount,
			SignTime:v.CreatedAt.Format("2006-01-02 15:04:05"),
		}
	}


	return reply, nil
}
