// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package house

import (
	"context"
	"encoding/json"
	"fmt"
	"property-garden/errors"
	dbmodel "property-garden/model"
	pb_v1 "property-garden/pb/v1"
	"property-garden/utils"
	"strings"
	"time"

	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
)

func checkBuildingAddParam(req *pb_v1.BuildingAddRequest) error {
	switch {
	case req.BuildingNumber == "":
		return status.Error(10003, "楼栋编号不能为空")
	case req.BuildingName == "":
		return status.Error(10003, "楼栋名称不能为空")
	case req.GardenId < 1:
		return status.Error(10003, "小区不能为空")
	case strings.Contains(req.BuildingNumber, "-"):
		return status.Error(10003, "楼栋号不能包含-")

	}
	return nil
}

//
func BuildingAdd(ctx context.Context, req *pb_v1.BuildingAddRequest) (reply *pb_v1.BuildingAddReply, err error) {

	reply = &pb_v1.BuildingAddReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()

	err = checkBuildingAddParam(req)
	if err != nil {
		return nil, err
	}
	dbname := utils.GetGardenDbName(req.GardenId)
	now := time.Now()
	building := dbmodel.TBuilding{
		//GardenId:req.GardenId,
		BuildingName:     req.BuildingName,
		BuildingNumber:   req.BuildingNumber,
		BuildingArea:     req.BuildingArea,
		BuildingUsedArea: req.BuildingUsedArea,
		Comment:          req.Comment,
		UpdatedAt:        now,
		CreatedAt:        now,
	}
	building.SetTable(dbname)
	db := database.DB()
	err = building.Insert(db)
	if err != nil {
		if strings.Contains(strings.ToLower(err.Error()), "duplicate") {
			return nil, errors.ErrRecordExist
		}
		return nil, errors.DataBaseError
	}
	reply.Id = building.ID

	return reply, nil
}
