// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package house

import (
	"context"
	"encoding/json"
	"fmt"
	"property-garden/errors"
	dbmodel "property-garden/model"
	pb_v1 "property-garden/pb/v1"
	"property-garden/utils"

	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
)

func checkHouseIdsParam(req *pb_v1.HouseIdsRequest) error {
	if req.GardenId < 1 {
		return status.Error(10003, "小区不能为空")
	}
	if req.UnitId == 0 && req.BuildingId == 0 && len(req.HouseIds) == 0{
		return  status.Error(10003, "楼栋，单元，房屋不能全为空")
	}
	return nil
}

//
func HouseIds(ctx context.Context, req *pb_v1.HouseIdsRequest) (reply *pb_v1.HouseIdsReply, err error) {

	reply = &pb_v1.HouseIdsReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()

	err = checkHouseIdsParam(req)
	if err != nil {
		return nil, err
	}
	dbname := utils.GetGardenDbName(req.GardenId)
	p := dbmodel.NewHouse(dbname)
	where := map[string]interface{}{}
	if req.GardenId > 0 {
		//where["garden_id"] = req.GardenId
	}
	if req.BuildingId > 0 {
		where["building_id"] = req.BuildingId
	}
	if req.UnitId > 0 {
		where["unit_id"] = req.UnitId
	}
	if req.HouseType > 0 {
		where["house_type"] = req.HouseType
	}
	if req.HouseNumber != "" {
		where["house_number"] = req.HouseNumber
	}
	if req.HouseStatus > 0 {
		where["status"] = req.HouseStatus
	}
	if req.Layer > 0 {
		where["layer"] = req.Layer
	}
	if len(req.HouseIds) > 0 {
		where["id in"] = req.HouseIds
	}

	ids, err := p.GetIds(database.DB(), where)
	if err != nil {
		return nil, errors.DataBaseError
	}
	reply.List = ids
	return reply, nil

}
