// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package house

import (
	"context"
	"encoding/json"
	"fmt"
	"gorm.io/gorm"
	"property-garden/errors"
	dbmodel "property-garden/model"
	pb_v1 "property-garden/pb/v1"
	"property-garden/utils"
	"strings"
	"time"

	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
)

func checkUnitAddParam(req *pb_v1.UnitAddRequest) error {
	switch {
	case req.UnitNumber < 0:
		return status.Error(10003, "单元编号不能为空")
	case req.UnitName == "":
		return status.Error(10003, "单元名称名称不能为空")
	case req.UnitLayers < 1:
		return status.Error(10003, "层数不能为空")
	case req.GardenId < 1:
		return status.Error(10003, "小区不能为空")
	case req.BuildingId < 1:
		return status.Error(10003, "楼栋id不能为空")

	}
	return nil
}

//
func UnitAdd(ctx context.Context, req *pb_v1.UnitAddRequest) (reply *pb_v1.UnitAddReply, err error) {

	reply = &pb_v1.UnitAddReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()

	err = checkUnitAddParam(req)
	if err != nil {
		return nil, err
	}
	dbname := utils.GetGardenDbName(req.GardenId)
	building := dbmodel.NewBuilding(dbname)
	where := map[string]interface{}{
		"id":req.BuildingId,
	}
	err = building.Find(database.DB(), where)
	if err != nil && err != gorm.ErrRecordNotFound {
		return nil, errors.DataBaseError
	}
	if building.ID == 0 {
		return nil, errors.ErrRecordNotFound
	}



	now := time.Now()
	hasLift := int64(2)
	if req.HasLift {
		hasLift = 1
	}
	unit := &dbmodel.TUnit{
		//GardenId:req.GardenId,
		UnitName:req.UnitName,
		UnitNumber:req.UnitNumber,
		UnitLayers:req.UnitLayers,
		BuildingId:req.BuildingId,
		HasLift:hasLift,
		UpdatedAt:      now,
		CreatedAt:      now,
	}
	db := database.DB()
	unit.SetTable(dbname)
	err = unit.Insert(db)
	if err != nil {
		if strings.Contains(strings.ToLower(err.Error()), "duplicate") {
			return nil, errors.ErrRecordExist
		}
		return nil, errors.DataBaseError
	}
	reply.Id = unit.ID


	return reply, nil
}

