// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package house

import (
	"context"
	"encoding/json"
	"fmt"
	"property-garden/errors"
	dbmodel "property-garden/model"
	pb_v1 "property-garden/pb/v1"
	"property-garden/utils"

	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
)

func checkUnitListParam(req *pb_v1.UnitListRequest) error {
	if req.Page == 0 {
		req.Page = 1
	}
	if req.PageSize == 0 {
		req.PageSize = 10
	}
	if req.GardenId < 1 && req.BuildingId < 1 {
		return errors.ParamsError
	}
	return nil
}

//
func UnitList(ctx context.Context, req *pb_v1.UnitListRequest) (reply *pb_v1.UnitListReply, err error) {

	reply = &pb_v1.UnitListReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()

	err = checkUnitListParam(req)
	if err != nil {
		return nil, err
	}
	dbname := utils.GetGardenDbName(req.GardenId)
	p := dbmodel.NewBuildingUnit(dbname)
	where := map[string]interface{}{}
	if req.GardenId > 0 {
		//where["garden_id"] = req.GardenId
	}
	if req.BuildingId > 0 {
		where["id"] = req.BuildingId
	}
	if req.UnitNumber > 0 {
		where["unit_number"] = req.UnitNumber
	}
	where["unit_id >"] = 0
	reply.Page = req.Page
	reply.Total, err = p.UnitCount(database.DB(), where, nil)
	if err != nil {
		return nil, errors.DataBaseError
	}
	if reply.Total == 0 {
		return reply, nil
	}
	list, err := p.UnitList(database.DB(), where, nil, int(req.Page), int(req.PageSize))
	if err != nil {
		return nil, errors.DataBaseError
	}
	reply.List = make([]*pb_v1.UnitItem, len(list))
	for i, v := range list {
		reply.List[i] = &pb_v1.UnitItem{

			Id:             v.UnitId,
			BuildingName:   v.BuildingName,
			BuildingId:     v.ID,
			UnitNumber:     v.UnitNumber,
			UnitName:       v.UnitName,
			UnitLayers:     v.UnitLayers,
			BuildingNumber: v.BuildingNumber,
		}
		if v.HasLift == 1 {
			reply.List[i].HasLift = true
		}
	}

	return reply, nil
}
