// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package house_rent

import (
	"context"
	"encoding/json"
	"fmt"
	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
	"property-garden/errors"
	dbmodel "property-garden/model"
	pb_v1 "property-garden/pb/v1"
	"property-garden/utils"
)

func checkGardenHouseRentInfoParam(req *pb_v1.GardenHouseRentInfoRequest) error {

	if req.GardenId < 1 {
		return status.Error(10003, "小区不能为空")
	}

	return nil
}

type HouseRentInfo struct {
	Count     int64
	RentPrice int64
	RoomArea  float64
}

//
func GardenHouseRentInfo(ctx context.Context, req *pb_v1.GardenHouseRentInfoRequest) (reply *pb_v1.GardenHouseRentInfoReply, err error) {

	reply = &pb_v1.GardenHouseRentInfoReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()

	err = checkGardenHouseRentInfoParam(req)
	if err != nil {
		return nil, err
	}
	dbname := utils.GetGardenDbName(req.GardenId)
	p := dbmodel.NewHouseRent(dbname)
	where := map[string]interface{}{
		"approve_status": 2,
	}
	str := "count(*) as count, sum(rent_price) as rent_price, sum(room_area) as room_area"
	result := []HouseRentInfo{}
	err = p.Select(database.DB(), where, nil, str, &result)
	if err != nil {
		return nil, errors.DataBaseError
	}
	if len(result) == 0 {
		return reply, nil
	}
	reply.RentCount = result[0].Count
	reply.AvgPrice = result[0].RentPrice / int64(result[0].RoomArea)

	return reply, nil
}
