// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package house_rent

import (
	"context"
	"encoding/json"
	"fmt"
	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
	"property-garden/errors"
	dbmodel "property-garden/model"
	pb_v1 "property-garden/pb/v1"
	"property-garden/utils"
)


func checkHouseRentDelManagerParam(req *pb_v1.HouseRentDelManagerRequest) error {
	switch {
	case req.GardenId < 1:
		return status.Error(10003, "小区不能为空")
	case req.Id < 1:
		return status.Error(10003, "绑定id不能为空")

	}
	return nil

}



//
func HouseRentDelManager(ctx context.Context, req *pb_v1.HouseRentDelManagerRequest) (reply *pb_v1.HouseRentDelManagerReply, err error) {

	reply = &pb_v1.HouseRentDelManagerReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()
	// 参数检查
	err = checkHouseRentDelManagerParam(req)
	if err != nil {
		return nil, err
	}
	dbname := utils.GetGardenDbName(req.GardenId)

	p := dbmodel.NewHouseRentManager(dbname)
	where := map[string]interface{}{
		"id":req.Id,
	}

	err = p.Delete(database.DB(), where)
	if err != nil {

		return nil, errors.DataBaseError
	}


	return reply, nil
}
