// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package house_rent

import (
	"context"
	"encoding/json"
	"fmt"
	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
	dbmodel "property-garden/model"
	"property-garden/pb"
	pb_v1 "property-garden/pb/v1"
	"property-garden/utils"
)


func checkHouseRentManagerListParam(req *pb_v1.HouseRentManagerListRequest) error {
	switch {
	case req.GardenId < 1:
		return status.Error(10003, "小区不能为空")
	case req.RentId < 1:
		return status.Error(10003, "租房id不能为空")

	}
	return nil

}

func getManagerInfos(ids []int64, gardenId int64) (map[int64]pb_v1.UserItem, error) {


	ret := map[int64]pb_v1.UserItem{}
	if len(ids) == 0 {
		return ret, nil
	}
	mreq := pb_v1.UserListRequest{
		GardenId:gardenId,
		Ids:ids,
		PageSize:-1,
		Page:-1,
	}
	mreply, err := pb.System.UserList(context.Background(), &mreq)
	if err != nil {
		return ret, err
	}
	for _, v := range mreply.List {
		ret[v.Id] = *v
	}


	return ret, nil

}

//
func HouseRentManagerList(ctx context.Context, req *pb_v1.HouseRentManagerListRequest) (reply *pb_v1.HouseRentManagerListReply, err error) {

	reply = &pb_v1.HouseRentManagerListReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()
	// 参数检查
	err = checkHouseRentManagerListParam(req)
	if err != nil {
		return nil, err
	}
	dbname := utils.GetGardenDbName(req.GardenId)

	p := dbmodel.NewHouseRentManager(dbname)
	where := map[string]interface{}{
		"rent_id":req.RentId,
	}
	list, err := p.List(database.DB(), where, nil, -1, -1)

	uids := []int64{}
	for _, v := range list {
		uids = append(uids, v.ManagerUid)
	}

	managerInfos, err := getManagerInfos(uids, req.GardenId)
	if err != nil {
		return nil, err
	}

	reply.List = make([]*pb_v1.HouseRentManagerItem, len(list))

	for i, v := range list {
		item := &pb_v1.HouseRentManagerItem{
			Id:v.ID,
			ManagerUid:v.ManagerUid,
			Name:managerInfos[v.ManagerUid].RealName,
			UserName:managerInfos[v.ManagerUid].UserName,
			Phone:managerInfos[v.ManagerUid].Phone,
			OpenimId:managerInfos[v.ManagerUid].OpenimId,
		}
		reply.List[i] = item
	}


	return reply, nil
}
