// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package household

import (
	"context"
	"encoding/json"
	"fmt"
	"property-garden/errors"
	dbmodel "property-garden/model"
	pb_v1 "property-garden/pb/v1"
	"property-garden/utils"
	"time"

	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
)

func checkHouseholdChangeParam(req *pb_v1.HouseholdChangeRequest) error {

	if len(req.GardenIds) == 0 ||
		req.Uid < 1 {
		return errors.ParamsError
	}
	return nil
}

//
func HouseholdChange(ctx context.Context, req *pb_v1.HouseholdChangeRequest) (reply *pb_v1.HouseholdChangeReply, err error) {

	reply = &pb_v1.HouseholdChangeReply{}
	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()

	err = checkHouseholdChangeParam(req)
	if err != nil {
		return nil, err
	}
	db := database.DB().Begin()
	where := map[string]interface{}{
		"uid": req.Uid,
	}
	values := map[string]interface{}{
		"updated_at": time.Now(),
	}
	uvalues := map[string]interface{}{
		"updated_at": time.Now(),
	}
	if req.IdType > 0 {
		//values["id_type"] = req.IdType
		uvalues["id_type"] = req.IdType
	}
	if req.Name != "" {
		//values["name"] = req.Name
		uvalues["real_name"] = req.Name
	}
	if req.IdNumber != "" {
		//values["id_number"] = req.IdNumber
		uvalues["id_number"] = req.IdNumber
	}
	if req.Phone != "" {
		values["phone"] = req.Phone
		uvalues["phone"] = req.Phone
	}
	if req.PublicOpenId != "" {
		values["public_open_id"] = req.PublicOpenId
		uvalues["public_open_id"] = req.PublicOpenId
	}
	if req.NickName != "" {
		uvalues["nick_name"] = req.NickName
	}
	filter := map[string]interface{}{
		"id": req.Uid,
	}
	for _, gardeId := range req.GardenIds {
		if len(values) > 0 {
			p := dbmodel.NewHouseApprovedGarden(utils.GetGardenDbName(gardeId))

			err = p.Update(db, where, values)
			if err != nil {
				db.Rollback()
				return nil, errors.DataBaseError
			}
		}

		u := dbmodel.NewHouseholdUser(utils.GetGardenDbName(gardeId))
		err = u.Update(db, filter, uvalues)
		if err != nil {
			db.Rollback()
			return nil, errors.DataBaseError
		}
	}

	db.Commit()

	return reply, nil
}
