// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package park

import (
	"context"
	"encoding/json"
	"fmt"
	"property-garden/errors"
	dbmodel "property-garden/model"
	pb_v1 "property-garden/pb/v1"
	"property-garden/utils"
	"strings"
	"time"

	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
)


func checkParkAddParam(req *pb_v1.ParkAddRequest) error {
	switch {
	case req.GardenId < 1:
		return status.Error(10003, "小区不能为空")
	case req.ParkName == "":
		return status.Error(10003, "停车场名称不能为空")
	case req.ParkNumber == "":
		return status.Error(10003, "停车场编号不能为空")
	case req.ParkType < 1:
		return status.Error(10003, "停车场类型不能为空")
	}
	return nil

}



//
func ParkAdd(ctx context.Context, req *pb_v1.ParkAddRequest) (reply *pb_v1.ParkAddReply, err error) {

	reply = &pb_v1.ParkAddReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()
	// 参数检查
	err = checkParkAddParam(req)
	if err != nil {
		return nil, err
	}
	dbname := utils.GetGardenDbName(req.GardenId)

	now := time.Now()
	p := &dbmodel.TPark{
		ParkType:req.ParkType,
		ParkNumber:req.ParkNumber,
		ParkName:req.ParkName,
		Comment:req.Comment,
		UpdatedAt:now,
		CreatedAt:now,
		//GardenId:req.GardenId,
	}
	p.SetTable(dbname)

	err = p.Insert(database.DB())
	if err != nil {

		if strings.Contains(strings.ToLower(err.Error()), "duplicate") {
			return nil, status.Error(10003, "该停车场已存在")
		}
		return nil, errors.DataBaseError
	}


	reply.Id = p.ID


	return reply, nil
}
