// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package park

import (
	"context"
	"encoding/json"
	"fmt"
	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
	"property-garden/errors"
	dbmodel "property-garden/model"
	pb_v1 "property-garden/pb/v1"
	"property-garden/utils"
)


//
func ParkList(ctx context.Context, req *pb_v1.ParkListRequest) (reply *pb_v1.ParkListReply, err error) {
	reply = &pb_v1.ParkListReply{}


	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()
	if req.GardenId < 1 {
		return nil, errors.ParamsError
	}
	dbname := utils.GetGardenDbName(req.GardenId)
	p := dbmodel.NewPark(dbname)
	where := map[string]interface{}{
		//"garden_id":req.GardenId,
	}
	list, err := p.List(database.DB(), where, nil, -1, -1)
	if err != nil {
		return nil, errors.DataBaseError
	}
	reply.List = make([]*pb_v1.ParkItem, len(list))
	for i, v := range list {
		reply.List[i] = &pb_v1.ParkItem{
			Id:v.ID,
			ParkName:v.ParkName,
			ParkNumber:v.ParkNumber,
			ParkType:v.ParkType,
			SpaceCount:v.SpaceCount,
			Comment:v.Comment,
			GardenId:req.GardenId,
			CreatedAt:v.CreatedAt.Format("2006-01-02 15:04:05"),
		}
	}


	return reply, nil
}
