// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package property_package

import (
	"context"
	"encoding/json"
	"fmt"
	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
	"gorm.io/gorm"
	"property-garden/errors"
	dbmodel "property-garden/model"
	pb_v1 "property-garden/pb/v1"
	"property-garden/utils"
)


func checkPropertyPackageDelParam(req *pb_v1.PropertyPackageDelRequest) error {
	switch {
	case req.GardenId == 0:
		return status.Error(10003, "小区不能为空")
	case req.Id < 1:
		return status.Error(10003, "id 不能为空")
	}
	return nil

}


func PropertyPackageDel(ctx context.Context, req *pb_v1.PropertyPackageDelRequest) (reply *pb_v1.PropertyPackageDelReply, err error) {

	reply = &pb_v1.PropertyPackageDelReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()
	// 参数检查
	err = checkPropertyPackageDelParam(req)
	if err != nil {
		return nil, err
	}

	dbname := utils.GetGardenDbName(req.GardenId)
	// 获取旧数据
	// 获取旧数据
	old := dbmodel.NewPropertyPackage(dbname)
	where := map[string]interface{}{
		"id":req.Id,
	}
	err = old.Find(database.DB(), where)
	if err != nil && err != gorm.ErrRecordNotFound {
		return nil, errors.DataBaseError
	}
	if old.ID == 0 {
		return nil, errors.ErrRecordNotFound
	}

	reply.Origin = &pb_v1.PropertyPackageUpdateRequest{
		GardenId:req.GardenId,
		Id:req.Id,
		GiveMonths:old.GiveMonths,
		GiveContent:old.GiveContent,
		PayMonths:old.PayMonths,
		PackageType:old.PackageType,
		Enable:false,
	}
	if old.Enable == 1 {
		reply.Origin.Enable = true
	}

	// 删除数据
	propertyPackage := dbmodel.NewPropertyPackage(dbname)

	err = propertyPackage.Delete(database.DB(), where)
	if err != nil {
		return nil, errors.DataBaseError
	}

	return reply, nil
}
