// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package property_package

import (
	"context"
	"encoding/json"
	"fmt"
	"property-garden/errors"
	dbmodel "property-garden/model"
	pb_v1 "property-garden/pb/v1"
	"property-garden/utils"

	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
)


func checkPropertyPackageListParam(req *pb_v1.PropertyPackageListRequest) error {
	switch {
	case req.GardenId == 0:
		return status.Error(10003, "小区不能为空")
	}
	if req.PageSize == 0 {
		req.PageSize = 10
	}
	if req.Page == 0 {
		req.Page = 1
	}

	return nil

}


func PropertyPackageList(ctx context.Context, req *pb_v1.PropertyPackageListRequest) (reply *pb_v1.PropertyPackageListReply, err error) {

	reply = &pb_v1.PropertyPackageListReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()
	// 参数检查
	err = checkPropertyPackageListParam(req)
	if err != nil {
		return nil, err
	}
	dbname := utils.GetGardenDbName(req.GardenId)
	p := dbmodel.NewPropertyPackage(dbname)
	where := map[string]interface{}{
		//"garden_id":req.GardenId,
	}
	reply.Page = req.Page
	reply.Total, err = p.Count(database.DB(), where, nil)
	if err != nil {
		return nil, errors.DataBaseError
	}
	if reply.Total == 0 {
		return reply, nil
	}
	list, err := p.List(database.DB(), where, nil, int(req.Page), int(req.PageSize))
	if err != nil {
		return nil, errors.DataBaseError
	}
	reply.List = make([]*pb_v1.PropertyPackageItem, len(list))
	for i, v := range list {

		item := &pb_v1.PropertyPackageItem{
			GiveContent:v.GiveContent,
			GiveMonths:v.GiveMonths,
			PackageType:v.PackageType,
			PayMonths:v.PayMonths,
			Enable:false,
			Id:v.ID,
		}
		if v.Enable == 1 {
			item.Enable = true
		}
		reply.List[i] = item
	}

	return reply, nil
}
