// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package repair

import (
	"context"
	"encoding/json"
	"fmt"
	"strings"
	"property-garden/errors"
	dbmodel "property-garden/model"
	pb_v1 "property-garden/pb/v1"
	"property-garden/utils"
	"time"

	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
)



func checkRepairClassAddParam(req *pb_v1.RepairClassAddRequest) error {

	switch {
	case req.GardenId == 0:
		return status.Error(10003, "小区不能为空")
	case req.Name == "":
		return status.Error(10003, "名称不能为空")
	case req.Area == 0:
		return status.Error(10003, "区域不能为空")
	}
	return nil
}


func RepairClassAdd(ctx context.Context, req *pb_v1.RepairClassAddRequest) (reply *pb_v1.RepairClassAddReply, err error) {

	reply = &pb_v1.RepairClassAddReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()
	// 参数检查
	err = checkRepairClassAddParam(req)
	if err != nil {
		return nil, err
	}
	now := time.Now()
	dbname := utils.GetGardenDbName(req.GardenId)
	enable := int32(1)
	if !req.Enable {
		enable = 2
	}
	p := dbmodel.TRepairClass{
		Name:req.Name,
		Enable:enable,
		UpdatedAt:now,
		CreatedAt:now,
		Area:req.Area,
	}
	p.SetTable(dbname)
	err = p.Insert(database.DB())
	if err != nil {
		if strings.Contains(strings.ToLower(err.Error()), "duplicate") {
			return nil, status.Error(10003, "分类名已存在")
		}
		return nil, errors.DataBaseError
	}
	reply.Id = p.ID

	return reply, nil
}
