// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package service_phone

import (
	"context"
	"encoding/json"
	"fmt"
	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
	"gorm.io/gorm"
	"property-garden/errors"
	dbmodel "property-garden/model"
	pb_v1 "property-garden/pb/v1"
	"property-garden/utils"
)


func checkServicePhoneClassDelParam(req *pb_v1.ServicePhoneClassDelRequest) error {
	switch {
	case req.GardenId == 0:
		return status.Error(10003, "小区不能为空")
	case req.Id < 1:
		return status.Error(10003, "id 不能为空")
	}
	return nil

}


func ServicePhoneClassDel(ctx context.Context, req *pb_v1.ServicePhoneClassDelRequest) (reply *pb_v1.ServicePhoneClassDelReply, err error) {

	reply = &pb_v1.ServicePhoneClassDelReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()
	// 参数检查
	err = checkServicePhoneClassDelParam(req)
	if err != nil {
		return nil, err
	}

	dbname := utils.GetGardenDbName(req.GardenId)
	// 获取旧数据
	old := dbmodel.NewServicePhoneClass(dbname)
	where := map[string]interface{}{
		"id":req.Id,
	}
	err = old.Find(database.DB(), where)
	if err != nil && err != gorm.ErrRecordNotFound {
		return nil, errors.DataBaseError
	}
	if old.ID == 0 {
		return nil, errors.ErrRecordNotFound
	}

	db := database.DB().Begin()
	defer func() {
		if err != nil {
			db.Rollback()
		}
	}()

	// 删除数据
	p := dbmodel.NewServicePhoneClass(dbname)

	err = p.Delete(db, where)
	if err != nil {
		return nil, errors.DataBaseError
	}

	servicePhone := dbmodel.NewServicePhone(dbname)
	where = map[string]interface{}{
		"class_id":req.Id,
	}
	err = servicePhone.Delete(db, where)
	if err != nil {
		return nil, errors.DataBaseError
	}
	db.Commit()
	return reply, nil
}
