// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package service_phone

import (
	"context"
	"encoding/json"
	"fmt"
	"gorm.io/gorm"
	"property-garden/errors"
	dbmodel "property-garden/model"
	pb_v1 "property-garden/pb/v1"
	"property-garden/utils"
	"strings"
	"time"

	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
)

func checkServicePhoneClassUpdateParam(req *pb_v1.ServicePhoneClassUpdateRequest) error {
	switch {
	case req.GardenId == 0:
		return status.Error(10003, "小区不能为空")
	case req.ClassName ==  "":
		return status.Error(10003, "名称不能为空")
	case req.Id == 0:
		return status.Error(10003, "id 不能为空")
	}
	return nil
}




func ServicePhoneClassUpdate(ctx context.Context, req *pb_v1.ServicePhoneClassUpdateRequest) (reply *pb_v1.ServicePhoneClassUpdateReply, err error) {

	reply = &pb_v1.ServicePhoneClassUpdateReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()
	// 参数检查
	err = checkServicePhoneClassUpdateParam(req)
	if err != nil {
		return nil, err
	}


	dbname := utils.GetGardenDbName(req.GardenId)
	// 获取旧数据
	old := dbmodel.NewServicePhoneClass(dbname)
	where := map[string]interface{}{
		"id":req.Id,
	}
	err = old.Find(database.DB(), where)
	if err != nil && err != gorm.ErrRecordNotFound {
		return nil, errors.DataBaseError
	}
	if old.ID == 0 {
		return nil, errors.ErrRecordNotFound
	}






	// 更新新数据
	now := time.Now()
	class := dbmodel.NewServicePhoneClass(dbname)
	enable := 1
	if !req.Enable {
		enable = 2
	}
	values := map[string]interface{}{
		"class_name":req.ClassName,
		"enable":enable,
		"updated_at":now,

	}

	where = map[string]interface{}{
		"id":req.Id,
	}

	err = class.Update(database.DB(), where, values)
	if err != nil {
		if strings.Contains(strings.ToLower(err.Error()), "duplicate") {
			return nil, status.Error(10003, "分类名已存在")
		}
		return nil, errors.DataBaseError
	}



	return reply, nil
}
