// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package service_phone

import (
	"context"
	"encoding/json"
	"fmt"
	"gorm.io/gorm"
	"property-garden/errors"
	dbmodel "property-garden/model"
	pb_v1 "property-garden/pb/v1"
	"property-garden/utils"
	"time"

	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
)



func checkServicePhoneAddParam(req *pb_v1.ServicePhoneAddRequest) error {

	switch {
	case req.GardenId == 0:
		return status.Error(10003, "小区不能为空")
	case req.ClassId == 0:
		return status.Error(10003, "分类不能为空")
	case req.Phone == "":
		return status.Error(10003, "电话不能为空")
	case req.Name == "":
		return status.Error(10003, "姓名不能为空")
	}
	return nil
}


func ServicePhoneAdd(ctx context.Context, req *pb_v1.ServicePhoneAddRequest) (reply *pb_v1.ServicePhoneAddReply, err error) {

	reply = &pb_v1.ServicePhoneAddReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()
	// 参数检查
	err = checkServicePhoneAddParam(req)
	if err != nil {
		return nil, err
	}
	now := time.Now()
	dbname := utils.GetGardenDbName(req.GardenId)

	class := dbmodel.NewServicePhoneClass(dbname)
	where := map[string]interface{}{
		"id":req.ClassId,
	}
	err = class.Find(database.DB(), where)
	if err != nil && err != gorm.ErrRecordNotFound{
		return nil, errors.DataBaseError
	}
	if class.ID == 0 {
		return nil, errors.ErrRecordNotFound
	}


	enable := int32(1)
	if !req.Enable {
		enable = 2
	}
	p := dbmodel.TServicePhone{
		Enable:enable,
		ClassId:req.ClassId,
		Name:req.Name,
		Phone:req.Phone,
		UpdatedAt:now,
		CreatedAt:now,
	}
	p.SetTable(dbname)
	err = p.Insert(database.DB())
	if err != nil {
		return nil, errors.DataBaseError
	}
	reply.Id = p.ID

	return reply, nil
}
