// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package system_msg

import (
	"context"
	"encoding/json"
	"fmt"
	"property-garden/errors"
	dbmodel "property-garden/model"
	pb_v1 "property-garden/pb/v1"
	"property-garden/utils"
	"time"

	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
)

func checkSystemMsgAddParam(req *pb_v1.SystemMsgAddRequest) error {
	switch {
	case req.GardenId < 1:
		return status.Error(10003, "小区不能为空")
	case req.Content == "":
		return status.Error(10003, "内容不能为空")
	case req.Code == "":
		return status.Error(10003, "消息code不能为空")
	}
	return nil

}

const (
	SystemMsgCodeHouseholdBindHouse    = "1"
	SystemMsgCodeRepairOrder           = "2"
	SystemMsgCodeRepairOrderSended     = "3"
	SystemMsgCodeSuggestionOrder       = "4"
	SystemMsgCodeSuggestionOrderSended = "5"
	SystemMsgCodeRent                  = "6"
	SystemMsgCodeRentAppointment       = "7"
	SystemMsgCodeFaceAdd               = "8"
)

//
func SystemMsgAdd(ctx context.Context, req *pb_v1.SystemMsgAddRequest) (reply *pb_v1.SystemMsgAddReply, err error) {

	reply = &pb_v1.SystemMsgAddReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()
	// 参数检查
	err = checkSystemMsgAddParam(req)
	if err != nil {
		return nil, err
	}
	dbname := utils.GetGardenDbName(req.GardenId)

	now := time.Now()
	p := &dbmodel.TMsg{
		Code:      req.Code,
		Content:   req.Content,
		UpdatedAt: now,
		CreatedAt: now,
		SystemUid: req.Uid,

		//GardenId:req.GardenId,
	}
	p.SetTable(dbname)

	err = p.Insert(database.DB())
	if err != nil {
		return nil, errors.DataBaseError
	}

	return reply, nil
}
