// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package system_msg

import (
	"context"
	"encoding/json"
	"fmt"
	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
	"property-garden/errors"
	dbmodel "property-garden/model"
	pb_v1 "property-garden/pb/v1"
	"property-garden/utils"
)

/*
func isParkBindCharge(id int64, dbname string) (bool, error) {
	p := dbmodel.NewChargeSpace(dbname)
	where := map[string]interface{}{
		"park_id":id,
	}
	count, err := p.Count(database.DB(), where, nil)
	if err != nil {
		return false, errors.DataBaseError
	}
	if count > 0 {
		return true, nil
	}
	return false, nil
}
*/

//
func SystemMsgReaded(ctx context.Context, req *pb_v1.SystemMsgReadedRequest) (reply *pb_v1.SystemMsgReadedReply, err error) {

	reply = &pb_v1.SystemMsgReadedReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()
	// 参数检查
	if len(req.Id) < 1 || req.GardenId < 1 {
		return nil, errors.ParamsError
	}
	dbname := utils.GetGardenDbName(req.GardenId)
	p := dbmodel.NewMsg(dbname)
	where := map[string]interface{}{
		"id in": req.Id,
	}

	err = p.Delete(database.DB(), where)
	if err != nil {
		return nil, errors.DataBaseError
	}

	return reply, nil
}
