// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package system_msg

import (
	"context"
	"encoding/json"
	"fmt"
	"git.getensh.com/common/gopkgs/database"
	"git.getensh.com/common/gopkgs/logger"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
	"property-garden/errors"
	dbmodel "property-garden/model"
	pb_v1 "property-garden/pb/v1"
	"property-garden/utils"
)

//
func SystemMsgList(ctx context.Context, req *pb_v1.SystemMsgListRequest) (reply *pb_v1.SystemMsgListReply, err error) {
	reply = &pb_v1.SystemMsgListReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()
	if req.GardenId < 1 {
		return nil, errors.ParamsError
	}
	if req.Uid < 1 {
		return nil, status.Error(10003, "uid不能为空")
	}
	if req.Page == 0 {
		req.Page = 1
	}
	if req.PageSize == 0 {
		req.PageSize = 10
	}
	dbname := utils.GetGardenDbName(req.GardenId)
	p := dbmodel.NewMsg(dbname)
	where := map[string]interface{}{
		fmt.Sprintf("system_uid=%d or system_uid=0", req.Uid): "",
	}

	reply.Page = req.Page
	reply.Total, err = p.Count(database.DB(), where, nil)
	if err != nil {
		return nil, errors.DataBaseError
	}
	if reply.Total == 0 {
		return reply, nil
	}
	list, err := p.List(database.DB(), where, nil, int(req.Page), int(req.PageSize))
	if err != nil {
		return nil, errors.DataBaseError
	}
	reply.List = make([]*pb_v1.SystemMsgItem, len(list))
	for i, v := range list {
		reply.List[i] = &pb_v1.SystemMsgItem{
			Id:        v.ID,
			Content:   v.Content,
			Code:      v.Code,
			CreatedAt: v.CreatedAt.Format("2006-01-02 15:04:05"),
		}
	}

	return reply, nil
}
