// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package model

import (
	"fmt"
	"git.getensh.com/common/gopkgs/logger"
	"git.getensh.com/common/gopkgs/util"
	"go.uber.org/zap"
	"gorm.io/gorm"
)

type TChargeUrge struct {
	ID int64 `gorm:"column:id;PRIMARY_KEY" json:"id"`
	//BillDay int64 `gorm:"column:bill_day" json:"bill_day"`
	UrgeDay int64 `gorm:"column:urge_day" json:"urge_day"`
	UrgeTarget int32 `gorm:"column:urge_target" json:"urge_target"`
	UrgeMsgType int32 `gorm:"column:urge_msg_type" json:"urge_msg_type"`
	table string
}

func (p *TChargeUrge) TableName() string {
	return p.table
}

func NewChargeUrge(database string) *TChargeUrge {
	return &TChargeUrge{table: fmt.Sprintf("%s.%s", database, "t_charge_urge")}
}

func (p *TChargeUrge) SetTable(database string)  {
	p.table = fmt.Sprintf("%s.%s", database, "t_charge_urge")
}


func (p *TChargeUrge) CreateTable(db *gorm.DB) error {
	sql :="CREATE TABLE IF NOT EXISTS "+p.TableName()+"("+
	"	`id` int(11) NOT NULL AUTO_INCREMENT,"+
	//"	`bill_day` int(10) NOT NULL COMMENT '账单生成日期',"+
	"`urge_day` int(10) NOT NULL DEFAULT '0' COMMENT '自动催缴日期：0 不催缴',"+
	"`urge_target` tinyint(1) NOT NULL COMMENT '1 仅业主 2 业主和家人 3 业主家人租客',"+
	"`urge_msg_type` tinyint(1) NOT NULL COMMENT '1 仅短信 2 仅微信 3 短信和微信',"+
	"PRIMARY KEY (`id`)"+
	") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin;"
	err := db.Exec(sql).Error
	if err != nil {
		logger.Error("mysql",
			zap.String("sql", "create table "+p.TableName()),
			zap.String("fields", ""),
			zap.String("error", err.Error()))
	}
	return err
}

func (p *TChargeUrge) Find(db *gorm.DB, where map[string]interface{}) error {
	err := db.Table(p.TableName()).Where(where).Find(p).Error
	if err != nil {
		fields, _ := util.MarshalToString(where)
		logger.Error("mysql",
			zap.String("sql", "select from "+p.TableName()),
			zap.String("fields", fields),
			zap.String("error", err.Error()))
	}

	return err
}

func (p *TChargeUrge) Last(db *gorm.DB) error {
	err := db.Table(p.TableName()).Last(p).Error
	if err != nil {
		logger.Error("mysql",
			zap.String("sql", "select last from "+p.TableName()),
			zap.String("fields", ""),
			zap.String("error", err.Error()))
	}

	return err
}

// Insert 插入一条记录
func (p *TChargeUrge) Insert(db *gorm.DB) error {
	err := db.Table(p.TableName()).Create(p).Error
	if err != nil {
		fields, _ := util.MarshalToString(*p)
		logger.Error("mysql",
			zap.String("sql", "insert into "+p.TableName()),
			zap.String("fields", fields),
			zap.String("error", err.Error()))
	}
	return err
}

// Insert 插入多条记录
func (p *TChargeUrge) InsertMulti(db *gorm.DB, values interface{}) error {
	err := db.Table(p.TableName()).Create(values).Error
	if err != nil {
		fields, _ := util.MarshalToString(*p)
		logger.Error("mysql",
			zap.String("sql", "insert into "+p.TableName()),
			zap.String("fields", fields),
			zap.String("error", err.Error()))
	}
	return err
}

func (p *TChargeUrge) Delete(db *gorm.DB, filter map[string]interface{}) error {
	cond, val, err := whereBuild(filter)
	if err != nil {
		return err
	}
	return db.Table(p.TableName()).Where(cond, val...).Delete(p).Error
}

func (p *TChargeUrge) Update(db *gorm.DB, where map[string]interface{}, values map[string]interface{}) error {
	cond, val, err := whereBuild(where)
	if err != nil {
		if err != nil {
			fields, _ := util.MarshalToString(values)
			logger.Error("mysql",
				zap.String("sql", "update "+p.TableName()),
				zap.String("fields", fields),
				zap.String("error", err.Error()))
		}
		return err
	}

	return db.Table(p.TableName()).Where(cond, val...).Updates(values).Error
}


func (p *TChargeUrge) UpdateByModel(db *gorm.DB) error {
	err := db.Table(p.TableName()).Model(p).Updates(p).Error
	if err != nil {
		fields, _ := util.MarshalToString(*p)
		logger.Error("mysql",
			zap.String("sql", "update "+p.TableName()),
			zap.String("fields", fields),
			zap.String("error", err.Error()))
	}
	return err
}

func (p *TChargeUrge) Count(db *gorm.DB, where map[string]interface{}, or map[string]interface{}) (int64, error) {

	cond, val, err := whereBuildAndOr(where, or)
	if err != nil {
		return 0, err
	}
	ret := int64(0)
	err = db.Table(p.TableName()).Where(cond, val...).Count(&ret).Error
	if err != nil {
		fields, _ := util.MarshalToString(where)
		logger.Error("mysql",
			zap.String("sql", "select count "+p.TableName()),
			zap.String("fields", fields),
			zap.String("error", err.Error()))
	}

	return ret, err
}

func (p *TChargeUrge) List(db *gorm.DB, where map[string]interface{}, or map[string]interface{}, page int, pageSize int) (list []TChargeUrge, err error) {

	cond, val, err := whereBuildAndOr(where, or)
	if err != nil {
		return list, err
	}
	if pageSize < 0 {
		result := db.Table(p.TableName()).Where(cond, val...).Find(&list)
		if result.Error != nil {
			wherefields, _ := util.MarshalToString(where)
			logger.Error("mysql",
				zap.String("sql", "select * from "+p.TableName()),
				zap.String("where", wherefields),
				zap.String("error", result.Error.Error()))
		}

		return list, result.Error
	}
	offset := (page - 1) * pageSize
	result := db.Table(p.TableName()).Where(cond, val...).Limit(pageSize).Offset(offset).Find(&list)
	if result.Error != nil {
		wherefields, _ := util.MarshalToString(where)
		logger.Error("mysql",
			zap.String("sql", "select * from "+p.TableName()),
			zap.String("where", wherefields),
			zap.String("error", result.Error.Error()))
	}

	return list, result.Error

}
